auraboros.debugs package
========================

Submodules
----------

auraboros.debugs.animation module
---------------------------------

.. automodule:: auraboros.debugs.animation
   :members:
   :undoc-members:
   :show-inheritance:

auraboros.debugs.entity module
------------------------------

.. automodule:: auraboros.debugs.entity
   :members:
   :undoc-members:
   :show-inheritance:

auraboros.debugs.gamemenu module
--------------------------------

.. automodule:: auraboros.debugs.gamemenu
   :members:
   :undoc-members:
   :show-inheritance:

auraboros.debugs.init\_for\_dev module
--------------------------------------

.. automodule:: auraboros.debugs.init_for_dev
   :members:
   :undoc-members:
   :show-inheritance:

auraboros.debugs.keyboard module
--------------------------------

.. automodule:: auraboros.debugs.keyboard
   :members:
   :undoc-members:
   :show-inheritance:

auraboros.debugs.particle module
--------------------------------

.. automodule:: auraboros.debugs.particle
   :members:
   :undoc-members:
   :show-inheritance:

auraboros.debugs.schedule module
--------------------------------

.. automodule:: auraboros.debugs.schedule
   :members:
   :undoc-members:
   :show-inheritance:

auraboros.debugs.shader module
------------------------------

.. automodule:: auraboros.debugs.shader
   :members:
   :undoc-members:
   :show-inheritance:

auraboros.debugs.stopwatch module
---------------------------------

.. automodule:: auraboros.debugs.stopwatch
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: auraboros.debugs
   :members:
   :undoc-members:
   :show-inheritance:
